################################################################################
# Model velocity of a sky diver
#
#    m dV/dt = mg - D
#
# where: m  = mass of sky diver
#        D  = drag acting on sky diver
#        g  = gravitational acceleration
#
# The implementation assumes the initial (vertical) velocity is zero 
#
# Drag is modeled as follows using a drag coefficient:
#
# D = 0.5*rhoa*V^2*Aref*CD
#  
# where: rhoa = density of atmosphere
#        Aref = reference area
#        CD   = drag coefficient
#
    
import skydive_model as sm
import matplotlib.pyplot as plt

p = {}
p['m']    = 80.0 # kg
p['rhoa'] = 1.0 # kg/m^3
p['g']    = 9.81 # gravity (m/s^2)

# The following CD and Aref are representative of a skydiver
# diving "orthogonal" to gravity (spread eagle)
p['CD']   = 1.0 # drag coefficient
p['Aref'] = 0.64 # m^2
        
tF = 100.0 # final time to simulate to (s)
dt = 0.1 # time increment to give solutions at (s)
    
t_eagle, V_eagle = sm.solve_skydive(tF, dt, p)

# This is for a skydiver in curled into a ball
p['CD']   = 0.4 # drag coefficient
p['Aref'] = 0.2 # m^2
t_ball, V_ball = sm.solve_skydive(tF, dt, p)

# This is for a skydiver in streamwise alignment (arrow)
p['CD']   = 0.1 # drag coefficient
p['Aref'] = 0.64 # m^2
t_arrow, V_arrow = sm.solve_skydive(tF, dt, p)

# Plot V vs t for all three cases overlayed
    
plt.plot(t_eagle,V_eagle,label='eagle')
plt.plot(t_ball,V_ball,label='ball')
plt.plot(t_arrow,V_arrow,label='arrow')
plt.xlabel('t (s)')
plt.ylabel('V (m/s)')
plt.title('Skydiver velocity vs. time')
plt.grid(True)
plt.legend()
