################################################################################
# Model velocity of a sky diver
#
#    m dV/dt = mg - D
#
# where: m  = mass of sky diver
#        D  = drag acting on sky diver
#        g  = gravitational acceleration
#
# The implementation assumes the initial (vertical) velocity is zero 
#
# Drag is modeled as follows using a drag coefficient:
#
# D = 0.5*rhoa*V^2*Aref*CD
#  
# where: rhoa = density of atmosphere
#        Aref = reference area
#        CD   = drag coefficient
#
# Note that dividing through by m gives the equation implemented:
#
#         dV/dt = g - D/m
#
    
import IVP

################################################################################
## Skydive class definition (a subclass of IVP)
################################################################################

class SkydiveIVP(IVP.IVP):

    def evalf(self, u, t):
        """
        
        Args:
            Tc (float list): current temperature of coffee.
            t (float): current time
    
        Returns:
            f (float list): forcing
    
        """
        
        m    = self.get_p('m')

        rhoa = self.get_p('rhoa')    
        Aref = self.get_p('Aref')
        CD   = self.get_p('CD')
    
        g    = self.get_p('g')
    
        V = u[0]
        
        D = 0.5*rhoa*(V**2)*Aref*CD
        f = g - D/m
            
        return [f]

def solve_skydive(tF, dt, p):
    
    skydive_IVP = SkydiveIVP([0.0], 0.0, tF, p)
    
    t, V = IVP.solve(skydive_IVP, dt, IVP.step_RK4)
    
    for i in range(len(t)):
        V[i] = V[i][0]
    
    return t, V


