################################################################################
# Model of water tank emptying
#
#    rho A_t dh/dt = -mdot_o
#
# where: rho    = density of water
#        A_t    = cross-sectional area of tank
#        h      = height of water (above orifice)
#        mdot_o = mass flow rate at orifice
#
# The mass flow rate at orifice is given by: 
#
# mdot_o = rho u_o A_o  
#
# where A_o is the cross-sectional area of the orifice, and
# the orifice velocity is modeled in the following ideal manner (assumes no losses)
#
# u_o = sqrt(2 g h)
#  
# where: g = gravity
    
import watertank_model as wm
import matplotlib.pyplot as plt

p = {}
p['A_t'] = 0.027 # m^2
p['A_o'] = 1.5e-5 # m^2
p['g']   = 9.81 # gravity (m/s^2)

hI = 0.146 # initial height of water (m)
tF = 175.0 # final time to simulate to (s)
dt = 1.0 # time increment to give solutions at (s)
    
t, h = wm.solve_watertank(hI, tF, dt, p)
    
plt.plot(t,h,label='Model')
plt.xlabel('t (s)')
plt.ylabel('h (m)')
plt.title('Water height vs. time')
plt.grid(True)

# Experimental results
texp = [  0.,  16.,  32.,  48.,  65.,  83., 103., 121., 144., 167.] # time (s)
hexp = [0.14605, 0.13335, 0.12065, 0.10795, 0.09525, 0.08255, 0.06985, 0.05715, 0.04445, 0.03175 ] # height (m)

plt.scatter(texp,hexp,c='r',marker='o',label='Experiment')
plt.legend()
